from datetime import date

class Hicham(): 
  
    def age(self):
        
        current_year = date.today().year
        
        print("age = " + str(current_year-1997))
        
    def nom(self): 
        
        print("nom : ZEKRI")
        
    def prenom(self): 
        
        print("prénom : Sidi Mohamed Hicham")
        
    def fonction(self): 
        
        print( "informaticien")
        


from setuptools import setup


requires = []


setup(
    name='hicham',
    version='0.2',
    description='Awesome library',
    url='',
    author='zekri sidi mohamed hicham',
    author_email='h.zekri@esi-sba.dz',
    license='MIT',
    keywords='this is me',
    packages=[
        "hicham"
    ],
    install_requires=requires,

)